==> nomachine-8.7.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXAuth.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXAuth::BEGIN{package NXAuth;no warnings;require warnings;do{
"\x77\x61\x72\x6e\x69\x6e\x67\x73"->import};}sub NXAuth::BEGIN{package NXAuth;no
 warnings;require Exporter;do{"\x45\x78\x70\x6f\x72\x74\x65\x72"->import};}sub 
NXAuth::BEGIN{package NXAuth;no warnings;require NXMsg;do{"\x4e\x58\x4d\x73\x67"
->import};}sub NXAuth::BEGIN{package NXAuth;no warnings;require Common::NXInfo;
do{"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x49\x6e\x66\x6f"->import};}package 
NXAuth;no warnings;(our (@ISA)="\x45\x78\x70\x6f\x72\x74\x65\x72");(our (@EXPORT
)=("\x67\x65\x74\x4e\x58\x41\x75\x74\x68\x54\x79\x70\x65",
"\x69\x73\x53\x53\x48\x44\x41\x75\x74\x68",
"\x69\x73\x4e\x6f\x74\x53\x53\x48\x44\x41\x75\x74\x68","\x69\x73\x4e\x58\x44",
"\x69\x73\x4e\x6f\x74\x4e\x58\x44",
"\x69\x73\x4e\x6f\x6d\x61\x63\x68\x69\x6e\x65",
"\x69\x73\x53\x79\x73\x74\x65\x6d"));($type=(""));($typeNomachine=
"\x6e\x6f\x6d\x61\x63\x68\x69\x6e\x65");($typeSystem="\x73\x79\x73\x74\x65\x6d")
;($typeNXD="\x6e\x78\x64");($salt=(""));($sshConnection=(-(0x151f+ 2759-0x1fe5))
);sub init{(my $environmentValue=libnxh::NXTransGetEnvironment (
"\x4e\x58\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"));if (defined (
$environmentValue)){if (($environmentValue ne (""))){setNXD ();}}}sub 
isSSHConnection{if (($sshConnection!=(-(0x0287+ 3591-0x108d)))){return (
$sshConnection);}($sshConnection=(0x0e25+ 3392-0x1b65));(my $env=
libnxh::NXTransGetEnvironment (
"\x53\x53\x48\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"));if (defined ($env))
{if (($env ne (""))){($sshConnection=(0x14bf+ 4051-0x2491));}}return (
$sshConnection);}sub initConnectionType{if (isNotNXD ()){if ((defined (
$GLOBAL::LOGGED_USER)and ($GLOBAL::LOGGED_USER ne ("")))){setSystem ();}else{
setNomachine ();}}}sub getNXAuthType{return ($type);}sub isSSHDAuth{if ((defined
 ($GLOBAL::UseSSHAuthentication)and ($GLOBAL::UseSSHAuthentication eq 
"\x65\x6e\x61\x62\x6c\x65\x64"))){return ((0x0208+ 8315-0x2282));}else{return (
(0x0bad+ 3651-0x19f0));}}sub isNotSSHDAuth{return ((!isSSHDAuth ()));}sub setNXD
{Logger::debug (((
"\x4e\x58\x41\x75\x74\x68\x3a\x20\x53\x65\x74\x20\x74\x79\x70\x65\x20\x27".
$typeNXD)."\x27\x2e"));($type=$typeNXD);}sub isTypeSet{if ((getNXAuthType ()ne 
(""))){return ((0x007b+  62-0x00b8));}return ((0x0cd8+ 2359-0x160f));}sub isNXD{
if (($type eq $typeNXD)){return ((0x0fb9+ 639-0x1237));}return (
(0x1814+ 2740-0x22c8));}sub isNotNXD{return ((!isNXD ()));}sub 
getActiveConnectionPort{if ((isNXD ()eq "\x31")){return (NXNodeInfo::getNxdPort 
());}else{return ($GLOBAL::SSHPort);}}sub setNomachine{if ((not (isTypeSet ())))
{Logger::debug (((
"\x4e\x58\x41\x75\x74\x68\x3a\x20\x53\x65\x74\x20\x74\x79\x70\x65\x20\x27".
$typeNomachine)."\x27\x2e"));($type=$typeNomachine);}}sub isNomachine{if (($type
 eq $typeNomachine)){return ((0x0a52+ 7213-0x267e));}return (
(0x04d4+ 4315-0x15af));}sub getTypeNomachine{return ($typeNomachine);}sub 
setSystem{if ((not (isTypeSet ()))){Logger::debug (((
"\x4e\x58\x41\x75\x74\x68\x3a\x20\x53\x65\x74\x20\x74\x79\x70\x65\x20\x27".
$typeSystem)."\x27\x2e"));($type=$typeSystem);}}sub isSystem{if (($type eq 
$typeSystem)){return ((0x024f+ 3203-0x0ed1));}return ((0x11bb+ 808-0x14e3));}sub
 getTypeSystem{return ($typeSystem);}sub checkIsSshAvailable{initConnectionType 
();if (isSystem ()){if (NXLicense::isSshFeature ()){if ((not (
NXSystemDaemons::isSSHEnabledInConfig ()))){Logger::debug (
"\x53\x53\x48\x20\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x64\x69\x73\x61\x62\x6c\x65\x64"
);return ((0x05f0+ 4751-0x187e));}}else{Logger::debug (
"\x53\x53\x48\x20\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6e\x6f\x74\x20\x73\x75\x70\x70\x6f\x72\x74\x65\x64"
);return ((0x0f11+ 4643-0x2132));}}return ((0x0a93+ 1720-0x114b));}sub 
NxServerUserSystemAuth{(my $hello_data=shift (@_));(my $helloMessage=((((
"\x68\x65\x6c\x6c\x6f\x20".$GLOBAL::MESSAGES_FORMAT{$GLOBAL::MSG_LOGIN_LOGIN}).
"\x20").$GLOBAL::LOGGED_USER).("\x20".$hello_data)));(my ($error_msg,$result)=
NXServer2Server::execute ($GLOBAL::MSG_GET_COMMAND,$helloMessage,"\x32\x35\x30",
(""),$GLOBAL::MSG_LOGIN_PASSWORD_AUTH_COOKIE,(""),"\x32\x35\x30",(""),
$GLOBAL::MSG_LOGIN_OK,("")));if ($result){NXMsg::register_error (
"\x4e\x58\x41\x75\x74\x68",
"\x65\x43\x61\x6e\x6e\x6f\x74\x41\x75\x74\x68\x6f\x72\x69\x7a\x65",
(0x107a+ 961-0x1247),
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x75\x74\x68\x6f\x72\x69\x7a\x65\x20\x77\x69\x74\x68\x20\x63\x6f\x6f\x6b\x69\x65"
);NXMsg::error (
"\x65\x43\x61\x6e\x6e\x6f\x74\x41\x75\x74\x68\x6f\x72\x69\x7a\x65",
"\x4e\x58\x41\x75\x74\x68");NXShell::handle_command ("\x65\x78\x69\x74");}return
 ((0x1985+ 2004-0x2159));}sub addCookie{(my $inputfilename=shift (@_));(my $dpyname
=shift (@_));(my $protoname=shift (@_));(my $hexkey=shift (@_));if (((not (
defined ($inputfilename)))or ($inputfilename eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x69\x6e\x70\x75\x74\x20\x66\x69\x6c\x65\x20\x6e\x61\x6d\x65\x2e"
);return ((0x002a+ 1834-0x0753));}if (((not (defined ($dpyname)))or ($dpyname eq
 ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x73\x70\x6c\x61\x79\x2e"
);return ((0x17c2+ 124-0x183d));}if (((not (defined ($protoname)))or ($protoname
 eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x6e\x61\x6d\x65\x2e"
);return ((0x15ca+ 1401-0x1b42));}if (((not (defined ($hexkey)))or ($hexkey eq 
("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x68\x65\x78\x6b\x65\x79\x2e"
);return ((0x138d+ 3663-0x21db));}(my $returnValue=libnxh::NXAddCookie (
$inputfilename,$dpyname,$protoname,$hexkey));if (($returnValue!=
(0x1166+ 566-0x139c))){(my $errorInt=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());Logger::warning (((((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x41\x64\x64\x43\x6f\x6f\x6b\x69\x65\x20\x66\x61\x69\x6c\x65\x64\x20\x77\x69\x74\x68\x20\x65\x72\x72\x6f\x72\x20\x63\x6f\x64\x65\x20\x5b"
.$errorInt)."\x5d\x20\x5b").$errorString)."\x5d"));}return ($returnValue);}sub 
isKnowHostSet{if ((defined ($setKnownhostNul)and ($setKnownhostNul==
(0x0e90+ 921-0x1228)))){return ((0x004d+ 6909-0x1b49));}return (
(0x0927+ 619-0x0b92));}sub generateSalt{Logger::debug (
"\x47\x65\x6e\x65\x72\x61\x74\x69\x6e\x67\x20\x73\x61\x6c\x74\x2e");($salt=
main::get_unique_id ());}sub getSalt{return ($salt);}return (
(0x0c23+  23-0x0c39));

==> nomachine-8.8.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXAuth.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXAuth::BEGIN{package NXAuth;no warnings;require warnings;do{
"\x77\x61\x72\x6e\x69\x6e\x67\x73"->import};}sub NXAuth::BEGIN{package NXAuth;no
 warnings;require Exporter;do{"\x45\x78\x70\x6f\x72\x74\x65\x72"->import};}sub 
NXAuth::BEGIN{package NXAuth;no warnings;require NXMsg;do{"\x4e\x58\x4d\x73\x67"
->import};}sub NXAuth::BEGIN{package NXAuth;no warnings;require Common::NXInfo;
do{"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x49\x6e\x66\x6f"->import};}package 
NXAuth;no warnings;(our (@ISA)="\x45\x78\x70\x6f\x72\x74\x65\x72");(our (@EXPORT
)=("\x67\x65\x74\x4e\x58\x41\x75\x74\x68\x54\x79\x70\x65",
"\x69\x73\x53\x53\x48\x44\x41\x75\x74\x68",
"\x69\x73\x4e\x6f\x74\x53\x53\x48\x44\x41\x75\x74\x68","\x69\x73\x4e\x58\x44",
"\x69\x73\x4e\x6f\x74\x4e\x58\x44",
"\x69\x73\x4e\x6f\x6d\x61\x63\x68\x69\x6e\x65",
"\x69\x73\x53\x79\x73\x74\x65\x6d"));($type=(""));($typeNomachine=
"\x6e\x6f\x6d\x61\x63\x68\x69\x6e\x65");($typeSystem="\x73\x79\x73\x74\x65\x6d")
;($typeNXD="\x6e\x78\x64");($salt=(""));($sshConnection=(-(0x0f23+ 3745-0x1dc3))
);sub init{(my $environmentValue=libnxh::NXTransGetEnvironment (
"\x4e\x58\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"));if (defined (
$environmentValue)){if (($environmentValue ne (""))){setNXD ();}}}sub 
isSSHConnection{if (($sshConnection!=(-(0x10a9+ 751-0x1397)))){return (
$sshConnection);}($sshConnection=(0x0034+ 3902-0x0f72));(my $env=
libnxh::NXTransGetEnvironment (
"\x53\x53\x48\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"));if (defined ($env))
{if (($env ne (""))){($sshConnection=(0x13cd+ 4517-0x2571));}}return (
$sshConnection);}sub initConnectionType{if (isNotNXD ()){if ((defined (
$GLOBAL::LOGGED_USER)and ($GLOBAL::LOGGED_USER ne ("")))){setSystem ();}else{
setNomachine ();}}}sub getNXAuthType{return ($type);}sub isSSHDAuth{if ((defined
 ($GLOBAL::UseSSHAuthentication)and ($GLOBAL::UseSSHAuthentication eq 
"\x65\x6e\x61\x62\x6c\x65\x64"))){return ((0x0459+ 8104-0x2400));}else{return (
(0x230a+ 730-0x25e4));}}sub isNotSSHDAuth{return ((!isSSHDAuth ()));}sub setNXD{
Logger::debug (((
"\x4e\x58\x41\x75\x74\x68\x3a\x20\x53\x65\x74\x20\x74\x79\x70\x65\x20\x27".
$typeNXD)."\x27\x2e"));($type=$typeNXD);}sub isTypeSet{if ((getNXAuthType ()ne 
(""))){return ((0x199a+ 3044-0x257d));}return ((0x0e56+ 2588-0x1872));}sub isNXD
{if (($type eq $typeNXD)){return ((0x0729+ 1435-0x0cc3));}return (
(0x03ab+ 4930-0x16ed));}sub isNotNXD{return ((!isNXD ()));}sub 
getActiveConnectionPort{if ((isNXD ()eq "\x31")){return (NXNodeInfo::getNxdPort 
());}else{return ($GLOBAL::SSHPort);}}sub setNomachine{if ((not (isTypeSet ())))
{Logger::debug (((
"\x4e\x58\x41\x75\x74\x68\x3a\x20\x53\x65\x74\x20\x74\x79\x70\x65\x20\x27".
$typeNomachine)."\x27\x2e"));($type=$typeNomachine);}}sub isNomachine{if (($type
 eq $typeNomachine)){return ((0x1d0a+ 2227-0x25bc));}return (
(0x04cc+ 284-0x05e8));}sub getTypeNomachine{return ($typeNomachine);}sub 
setSystem{if ((not (isTypeSet ()))){Logger::debug (((
"\x4e\x58\x41\x75\x74\x68\x3a\x20\x53\x65\x74\x20\x74\x79\x70\x65\x20\x27".
$typeSystem)."\x27\x2e"));($type=$typeSystem);}}sub isSystem{if (($type eq 
$typeSystem)){return ((0x18ab+ 381-0x1a27));}return ((0x08d0+ 7153-0x24c1));}sub
 getTypeSystem{return ($typeSystem);}sub checkIsSshAvailable{initConnectionType 
();if (isSystem ()){if (NXLicense::isSshFeature ()){if ((not (
NXSystemDaemons::isSSHEnabledInConfig ()))){Logger::debug (
"\x53\x53\x48\x20\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x64\x69\x73\x61\x62\x6c\x65\x64"
);return ((0x0ee3+ 3741-0x1d7f));}}else{Logger::debug (
"\x53\x53\x48\x20\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6e\x6f\x74\x20\x73\x75\x70\x70\x6f\x72\x74\x65\x64"
);return ((0x0e19+ 1985-0x15d8));}}return ((0x0668+ 4801-0x1929));}sub 
NxServerUserSystemAuth{(my $hello_data=shift (@_));(my $helloMessage=((((
"\x68\x65\x6c\x6c\x6f\x20".$GLOBAL::MESSAGES_FORMAT{$GLOBAL::MSG_LOGIN_LOGIN}).
"\x20").$GLOBAL::LOGGED_USER).("\x20".$hello_data)));(my ($error_msg,$result)=
NXServer2Server::execute ($GLOBAL::MSG_GET_COMMAND,$helloMessage,"\x32\x35\x30",
(""),$GLOBAL::MSG_LOGIN_PASSWORD_AUTH_COOKIE,(""),"\x32\x35\x30",(""),
$GLOBAL::MSG_LOGIN_OK,("")));if ($result){NXMsg::register_error (
"\x4e\x58\x41\x75\x74\x68",
"\x65\x43\x61\x6e\x6e\x6f\x74\x41\x75\x74\x68\x6f\x72\x69\x7a\x65",
(0x06e4+ 8511-0x262f),
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x75\x74\x68\x6f\x72\x69\x7a\x65\x20\x77\x69\x74\x68\x20\x63\x6f\x6f\x6b\x69\x65"
);NXMsg::error (
"\x65\x43\x61\x6e\x6e\x6f\x74\x41\x75\x74\x68\x6f\x72\x69\x7a\x65",
"\x4e\x58\x41\x75\x74\x68");NXShell::handle_command ("\x65\x78\x69\x74");}return
 ((0x1109+ 3428-0x1e6d));}sub addCookie{(my $inputfilename=shift (@_));(my $dpyname
=shift (@_));(my $protoname=shift (@_));(my $hexkey=shift (@_));if (((not (
defined ($inputfilename)))or ($inputfilename eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x69\x6e\x70\x75\x74\x20\x66\x69\x6c\x65\x20\x6e\x61\x6d\x65\x2e"
);return ((0x0615+ 4937-0x195d));}if (((not (defined ($dpyname)))or ($dpyname eq
 ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x73\x70\x6c\x61\x79\x2e"
);return ((0x0b25+ 5482-0x208e));}if (((not (defined ($protoname)))or (
$protoname eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x6e\x61\x6d\x65\x2e"
);return ((0x1cdc+ 2051-0x24de));}if (((not (defined ($hexkey)))or ($hexkey eq 
("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x68\x65\x78\x6b\x65\x79\x2e"
);return ((0x00a4+ 6135-0x189a));}(my $returnValue=libnxh::NXAddCookie (
$inputfilename,$dpyname,$protoname,$hexkey));if (($returnValue!=
(0x075b+ 4980-0x1acf))){(my $errorInt=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());Logger::warning (((((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x41\x64\x64\x43\x6f\x6f\x6b\x69\x65\x20\x66\x61\x69\x6c\x65\x64\x20\x77\x69\x74\x68\x20\x65\x72\x72\x6f\x72\x20\x63\x6f\x64\x65\x20\x5b"
.$errorInt)."\x5d\x20\x5b").$errorString)."\x5d"));}return ($returnValue);}sub 
isKnowHostSet{if ((defined ($setKnownhostNul)and ($setKnownhostNul==
(0x0c49+ 1943-0x13df)))){return ((0x0feb+ 5918-0x2708));}return (
(0x045f+ 5785-0x1af8));}sub generateSalt{Logger::debug (
"\x47\x65\x6e\x65\x72\x61\x74\x69\x6e\x67\x20\x73\x61\x6c\x74\x2e");($salt=
main::get_unique_id ());}sub getSalt{return ($salt);}return (
(0x040f+ 4418-0x1550));
